@@ -8,7 +8,7 @@ import functools
 import itertools
 import os
 import pathlib
-from typing import Any, Callable, Generator, Iterable, Optional, Union
+from typing import Any, Callable, Generator, Iterable, MutableMapping, Optional, Union
 
 import np_config
 import np_logging
@@ -357,9 +357,13 @@ class Session:
         else:
             return from_lims
     
-    @cached_property
-    def state(self) -> State:
-        return State(self.id)
+    @property
+    def state(self) -> MutableMapping[str, Any]:
+        try:
+            return State(self.id)
+        except Exception as exc:
+            logger.error("Failed to load `%r.state`: %r", self, exc)
+        return {}
     
     def find_platform_json(self) -> pathlib.Path | None:
         """Find the platform.json file for this session, if it exists."""
@@ -611,9 +615,30 @@ def cleanup_npexp():
             else:
                 logger.info("Moved %s to habituation/backup", _.name)
                 
+                
+def latest_session(
+        project: str | Project | Projects,
+        session_type: Literal["ephys", "hab", "behavior"] = "ephys"
+    ) -> Session | None:
+    
+    if isinstance(project, str):
+        if project.upper() in Projects.__members__:
+            project = Projects[project.upper()]
+            
+    session: int | None = None
+    if isinstance(project, Projects):
+        session = project.latest_session(session_type)
+    if isinstance(project, Project):
+        session = project.state.get(f'latest_{session_type}')
+    if session is None:
+        logger.info("No latest session found for %s", project)
+        return None
+    
+    return Session(session)
+    
 if __name__ == "__main__":
     logger = np_logging.getLogger()
-    cleanup_npexp()
+    latest_session('TTN')
     if is_connected("lims2"):
         doctest.testmod(verbose=True)
         # optionflags=(doctest.ELLIPSIS, doctest.NORMALIZE_WHITESPACE,
